;-===============================================================================;
;- Copyright (C) 2000 H-Peter Recktenwald, Berlin <phpr@snafu.de>
;- Read LICENSE file for full copyright information (GNU GPL)
;-
;-  file  	: cpucaps.inc
;-  switch	: _AMD_CAPS_H
;-  created	: 05-mar-2000
;-  modified	: 05-apr-2000
;-  version	: 0.12 : date added
;-		: 0.11 : 18-mar-2000
;-  assembler	: nasm 0.98
;-  description	: option strings & cpu capabilities for "cpuid.asm",
;-		; this file lists the numeric querystring substitutions.
;-  author	: H-Peter Recktenwald, Berlin <phpr@snafu.de>
;-  comment	: to be included in "cpuid.asm".
;-		: Append any new data to the appropriate section and keep
;-		: in sync with "cpuid.asm", <jmptab> and destn. labels.
;-		: (may be automatted with "qm" of UQLX, running "addstr_prg"
;-		: (UQLX: http://www.geocities.com/SiliconValley/Bay/2602
;-		: Don't rely on "known" code values, to maintain extendability.
;-  source	: adetect.h by AMD, others by Intel (re cpuid.gls, cpuid.asm)
;-  requires	: - (have bravery, persistency, and almost endless patient be) -
;-===============================================================================;
;-
;-

%ifndef _AMD_CAPS_H
%define _AMD_CAPS_H

;; "future proof" & flexible maintanance:							;;
; 1)	when referring to a labeled section don't use just the section label
;	by it's own, always append the .TOP or .BOT local labels rsp.
; 2)	keep the complete list of labels and "name"s in sync with the jump table
;	in cpuid.asm, at <jmptab>
; 3)	keep the list of VENDOR_NAME in sync with VENDOR_ID
; 4)	always add new entries to the apporopriate section, if present,
;	else create a new section according to the pattern, below, with
;	ENTRY_LABEL, .UNKN, .BOT, .{new entries}, .TOP.
;	Don't forget to updating the main jump table! (use "addstr_bas" if posible)
; 5)	Entry length is 4 bytes, constant, with the only exception of VENDOR_NAMEs!
;
%ifndef DATE
%define DATE '20000404'
%endif
helpt:	db VER,':',DATE,".hpr, cpuid"
.e:
blank:	db ' [[option] [query]] ...',eol,tab
	db 'output options:',eol,tab,tab
	db '-n decimal -x sedecimal -o octal -b binary numbers',eol,tab,tab
	db '-s short -l long strings  -v version  -? {special}',eol,tab,tab
	db "+option: reset",eol,tab
	db "query:",eol,tab,tab
	db "string | '0'octal | decimal | '0x'sedecimal | (none: -h)",eol,tab,tab
	db "(some 100+ valid queries exist, re 'cpucaps.gls')"
eolt:	db eol
mptyt:	db NULL
noidt:	db '"CPUID" '
quert:	db 'not implemented',NULL	; -l if "unkn", query code ovf, no cpuid call

		align 8			; speed up(?) querystring searching
VNAME:
		db	'none'		; id for no-cpuid & index:=0 (and align QUERY to 8/32)
.BOT:
.AMD:		db	'AuthenticAMD'	;v0
.INTEL:		db	'GenuineIntel'	;v1
.CYRIX:		db	'CyrixInstead'	;v2
.CTAUR: 	db	'CentaurHauls'	;v3
.UMC:		db	'UMC UMC UMC '	;v4
.UNKN:		db	'VendrUnknown'	;v5
.UNKN2:		db	'VendrUnknown'	;v6 ; keep in sync with id-strings, below
.NONE:		db	'No Vendor ID'	;v7 ; ovf value, do not change unless mask in asm adjusted
.TOP:
; ------------------------------------------------------------------------------------------------ ;
;; trailing ":" leading the query number are required for the numbering program	;:  ;;DO NOT CHANGE;
;; LABEL     Query-/Response-Stg::	Comment			Query Numbers ->;:nn;;DO NOT CHANGE;
; ------------------------------------------------------------------------------------------------ ;
QUERY:
.BOT:
.UNKN:		dd "unkn"	;;0						;:00
OPTIONS:			;;			query by number(decimal); nn
.BOT:
.HELP:		dd '-h  '	;;			"help"			;:01
.HELPL:		dd '--he'	;;			"lhel"			;:02
.VERS:		dd '-v  '	;;			"vers"			;:03
.VERSL:		dd '--ve'	;; 			"lver"			;:04
.STRG:		dd '-s  '	;; string		"strg"			;:05
.OBIN:		dd '-b  '	;; binary		"obin"			;:06
.CNUM:		dd '-n  '	;; significant dig only	"cnum"			;:07
.ONUM:		dd '-o  '	;; octal		"ooct"			;:08
.LNAM:		dd '-l  '	;; (long) namestring	"lnam"			;:09
.BL:		dd '-t  '	;;			"sbl "			;:10
.OHEX:		dd '-x  '	;; sedecimal		"ohex"			;:11
.XSTG:		dd '+s  '	;; reset cap string	"rstg"			;:12
.XBIN:		dd '+b  '	;;			"rbin"			;:13
.XCNM:		dd '+n  '	;; 			"rcnm"			;:14
.XONM:		dd '+o  '	;; 			"roct"			;:15
.XLNM:		dd '+l  '	;; 			"rlnm"			;:16
.XBL:		dd '+t  '	;;			"rbl "			;:17
.XOHX:		dd '+x  '	;;			"rohx"			;:18
.QUST:		dd '-?  '	;;			"qust"			;:19
.TOP:

;; Detected CPU Vendors								;
VENDOR:				;ix;nr. (index ret from "st2ix" is ix+1)
.BOT:
.UNKN:		dd "unkn"	;;0	:					;:20
.AMD:		dd "amd "	;;1	:0					;:21
.INTEL:		dd "intl"	;;2	:1					;:22
.CYRIX:		dd "cyrx"	;;3	:2					;:23
.CTAUR:		dd "cntr"	;;4	:3					;:24
.UMC:		dd "umc "	;;5	:4					;:25
		dd "unkn"	;;6	:5 keep in sync with long names, above	;:26
		dd "unkn"	;;7	:6					;:27
.NONE:		dd "noid"	;;8	:7					;:28
.TOP:
QUERY.FIRST: equ VENDOR.AMD	;; 	:  base index for '-? -?'		;;

CPU:
.BOT:
.UNKN:		dd "unkn"	;;0	:					;:29
.I386:		dd "i386"	;;1	: no cpuid				;:30
.I486:		dd "i486"	;;2	:					;:31
.I586:		dd "i586"	;;2	:					;:32
.I686:		dd "i686"	;;2	:					;:33
.I786:		dd "i786"	;;2	:					;:34
.A486:		dd "a486"	;;3	:					;:35
.K5:		dd "k5  "	;;4	:					;:36
.K6:		dd "k6  "	;;5	:					;:37
.K6_2:		dd "k6_2"	;;6	:					;:38
.K6_3:		dd "k6_3"	;;7	:					;:39
.ATHLON:	dd "atln"	;;8	:					;:40
.I486DX:	dd "i4dx"	;;9	: no cpuid				;:41
.I486SX:	dd "i4sx"	;;10	: no cpuid				;:42
.I486DX2:	dd "i4d2"	;;11	: find 'overdrive's by xtyp		;:43
.I486SL:	dd "i4sl"	;;12	:					;:44
.I486SX2:	dd "i4x2"	;;13	:					;:45
.I486DX2E:	dd "i4e2"	;;14	:					;:46
.I486DX4:	dd "i4x4"	;;15	: find 'overdrive's by xtyp		;:47
.Pentium:	dd "p586"	;;16	: find 'overdrive's by xtyp		;:48
.Pentium_MMX:	dd "i5mx"	;;17	:					;:49
.Pentium_Pro:	dd "i6pr"	;;18	:					;:50
.Pentium_II:	dd "i6p2"	;;19	: find 'overdrive's by xtyp		;:51
.Celeron:	dd "i6ce"	;;20	:					;:52
.Pentium_III:	dd "i6p3"	;;21	: find 'xeon' by cache cfg (1/2M)	;:53
.U386:		dd "u386"	;;22	: no cpuid				;:54
.U486:		dd "u486"	;;23	:					;:55
.U586:		dd "u586"	;;24	:					;:56
.U686:		dd "u686"	;;25	:					;:57
.U786:		dd "u786"	;;26	:					;:58
.TOP:
;; Detected CPU capabilities - Synthesized values				;
CAP:
.BOT:
.VENDOR:	dd "vend"	;;0	:- Manufacturer				;:59
.TYPE:		dd "type"	;;1	:- CPU type				;:60
.CPUVENDOR:	dd "vstg"	;;2	:- CPU vendor name string		;:61
.CPUNAME:	dd "name"	;;3	:- CPU Processor string			;:62
.CPUID:		dd "cpid"	;;4	:- Supports CPUID instruction		;:63
.FEAT:		dd "feat"	;;5	:- Processor features list		;:64
.XTYP:		dd "xtyp"	;;0	:I:proc-type query			;:65
.REGS:		dd "regs"	;;6	:  CPUID all levels reg values		;:66
.CACH:		dd "cach"	;;7	:  cache configuration parameters	;:67
.OEM:		dd "oem "	;;1	:I:proc-type				;:68
.OVDV:		dd "ovdv"	;;2	:I:proc-type				;:69
.DUAL:		dd "dual"	;;3	:I:multi/dual proc env.			;:70
.ITYP:		dd "ityp"	;;4	:I:proc-type, intel reserved		;:71
.SSE_MMX:	dd "ssem"	;;25+mmx:A:SSE MMX if sse and mmx	
	;:72
.SSE_FP:	dd "ssef"	;;25+xfp:A:SSE FP: orps xmm0,xmm0 if sse-bit set;:73
.SERNO:		dd "psn "	;;18+l3	:I level 3 96 bit serial number		;:74
.FBOT:		equ .SERNO
;; Standard Processor Feature Bits - returned as boolean values
			;
;					;ln;bit#;idx
.FPU:		dd "fpu "	;;00 3b	:- FPU present				;:75
.VME:		dd "vme "	;;01 3c	:- Virtual Mode Extensions		;:76
.DEBUG:		dd "de  "	;;02 3d	:- Debug extensions			;:77
.PSE:		dd "pse "	;;03 3e	:- Page Size Extensions			;:78
.TSC:		dd "tsc "	;;04 3f	:- Time Stamp Counter			;:79
.MSR:		dd "msr "	;;05 40	:- Model Specific Registers		;:80
.PAE:		dd "pae "	;;06 41	:- Page Address Extensions		;:81
.MCE:		dd "mce "	;;07 42	:- Machine Check Extensions		;:82
.CMPXCHG8:	dd "cx8 "	;;08 43	:- CMPXCHG8 instruction			;:83
.APIC:		dd "apic"	;;09 44	:- APIC					;:84
		dd "unkn"	;;10 45	:- reserved				;:85
.SYSENTER:	dd "sep "	;;11 46	:- SYSENTER/SYSEXIT instruction		;:86
.MTRR:		dd "mtrr"	;;12 47	:- Memory Type Range Registers		;:87
.GPE:		dd "pge "	;;13 48	:- Global Paging Extensions		;:88
.MCA:		dd "mca "	;;14 49	:- Machine Check Architecture		;:89
.CMOV:		dd "cmov"	;;15 4a	:- CMOV instruction			;:90
.PAT:		dd "pat "	;;16 4b	:- Page Attribue Table			;:91
.PSE36:		dd "ps36"	;;17 4c	:- PSE36 (Page Size Extensions)		;:92
.PN:		dd "pn  "	;;18 4d	:I 96-bit number feature enabled	;:93
		dd "unkn"	;;19	:					;:94
		dd "unkn"	;;20	:					;:95
		dd "unkn"	;;21	:					;:96
.MMX_EXT:	dd "xmmx"	;;22 51	:A MMX Extensions			;:97
.MMX:		dd "mmx "	;;23 52	:  MMX support				;:98
.FXSAVE:	dd "fxsr"	;;24 53	:  FXSAVE/FXRSTOR instruction		;:99
.SSE:		dd "sse "	;;25 54	:A AMD SSE ident. Intel .HAS_SIMD_EXT	;:00
		dd "unkn"	;;26	:					;:01
		dd "unkn"	;;27	:A:SSE MMX if sse and mmx	
	;:02
		dd "unkn"	;;28	:A SSE
					;:03
.L64M:		dd "l64m"	;;29	:A:64bit long mode, SSE FP: orps xmm0,xmm0 if sse-bit set;:04
.3DNOW_EXT:	dd "x3dn"	;;30 59	:A Extended 3DNow! support
		;:05
.3DNOW:		dd "a3dn"	;;31 5a	:A 3DNow! support
			;:06
.TOP:				;	- sythesized featurebits -		;;--
.SIMD_EXT:	dd "simd"	;;25	:I Streaming SIMD supp 			;:07
; query by name == response strings
; query by number == cache config value
L1:
;;	    positions in (blockwise reverse) sync with asm labels. don't change!	;  :OK:
;; LABEL     Query-/Response-Stg::	Comment			Query Numbers	-> 100+;:nn;;;
.BOT:
;; AMD Cache parameters (not all values apply to all CPUs)				;
.EDTLB_ASSOC:	dd "x1da"	;;- Extd (2/4 Mbyte) L1 Data Cache TLB Ass (0xff = full);:08
.EDTLB_ENTRIES:	dd "x1de"	;;- Extd (2/4 Mbyte) L1 Data Cache TLB Entries
		;:09
.EITLB_ASSOC:	dd "x1ia"	;;- Extd (2/4 Mbyte) L1 Instruction Cache TLB Ass	;:10
.EITLB_ENTRIES:	dd "x1ie"	;;- Extd (2/4 Mbyte) L1 Instruction Cache TLB Entries
	;:11
.DTLB_ASSOC:	dd "t1da"	;;- L1 Data Cache TLB Associativity
			;:12
.DTLB_ENTRIES:	dd "t1de"	;;- L1 Data Cache TLB Entries
				;:13
.ITLB_ASSOC:	dd "t1ia"	;;- L1 Instruction Cache TLB Associativity (0xff = full);:14
.ITLB_ENTRIES:	dd "t1ie"	;;- L1 Instruction Cache TLB Entries
			;:15
.DCACHE_SIZE:	dd "l1ds"	;;- L1 Data Cache Size (kbytes)
				;:16
.DCACHE_ASSOC:	dd "l1da"	;;- L1 Data Cache Associativity (0xff = full)		;:17
.DCACHE_LINES:	dd "l1cl"	;;- L1 Data Cache Lines
					;:18
.DCACHE_LSIZE:	dd "l1cz"	;;- L1 Data Cache Line Size (bytes)
			;:19
.ICACHE_SIZE:	dd "l1is"	;;- L1 Instruction Cache Size (kbytes)
			;:20
.ICACHE_ASSOC:	dd "l1ia"	;;- L1 Instruction Cache Associativity (0xff = full ass);:21
.ICACHE_LINES:	dd "l1il"	;;- L1 Instruction Cache Lines
				;:22
.ICACHE_LSIZE:	dd "l1iz"	;;- L1 Instruction Cache Line Size (bytes)
		;:23
.TOP:
L2:
.BOT:
.AMD:
.EDTLB_ASSOC:	dd "x2da"	;;- Extd (2/4 Mbyte) L2 Data Cache TLB Ass (0xf = full)	;:24
.EDTLB_ENTRIES:	dd "x2de"	;;- Extended (2/4 Mbyte) L2 Data Cache TLB Entries
	;:25
.EUTLB_ASSOC:	dd "x2ia"	;;- Extd (2/4 Mb) L2 Instruction or Uni Cache TLB Ass	;:26
.EUTLB_ENTRIES:	dd "x2ie"	;;- Extd (2/4 Mb) L2 Inst or Unified Cache TLB Entries	;:27
.DTLB_ASSOC:	dd "t2da"	;;- L2 Data Cache TLB Associativity
			;:28
.DTLB_ENTRIES:	dd "t2de"	;;- L2 Data Cache TLB Entries
				;:29
.UTLB_ASSOC:	dd "t2ia"	;;- L2 Instruction or Unified Cache TLB Ass (0xf = full);:30
.UTLB_ENTRIES:	dd "t2ie"	;;- L2 Instruction or Unified Cache TLB Entries
		;:31
.CACHE_SIZE:	dd "l2us"	;;- L2 Unified Cache Size (Kbytes)
			;:32
.CACHE_ASSOC:	dd "l2ua"	;;- L2 Unified Cache Associativity (0xf = full ass)	;:33
.CACHE_LINES:	dd "l2ul"	;;- L2 Unified Cache Lines (lines per tag)
		;:34
.CACHE_LSIZE:	dd "l2uz"	;;- L2 Unified Cache Line Size (bytes)
			;:35
.INTEL:
;; Intel Cache parameters	::	keep sequence synchronous to <icache> list	;;
.IT32:		dd "it32"	;;Instr TLB, 4K Pages, 4-way set associative, 32 entries;:36
.IT04:		dd "it02"	;;Instr TLB, 4M Pages, fully associative, 2 entries	;:37
.DT4K:	        dd "dt4k"	;;Data TLB, 4K Pages, 4-way set associative, 64 entries	;:38
.DT4N:	        dd "dt4m"	;;Data TLB, 4M Pages, 4-way set associative, 8 entries	;:39
.IC8:		dd "ic8 "	;;Instr Cache, 8K, 4-way set associative, 32b line size	;:40
.IC16:	        dd "ic16"	;;Instr Cache, 16K, 4-way set associative, 32b line size;:41
.DC8:		dd "dc8 "	;;Data Cache, 8K, 2-way set associative, 32b line size	;:42
.DC16:	        dd "dc16"	;;Data Cache, 16K, 2-way set associative, 32b line size	;:43
.NL2:	        dd "nl2 "	;;No L2 Cache						;:44
.UC1:	        dd "uc1 "	;;Unified, 32b cache line, 4-way set associative, 128K	;:45
.UC2:	        dd "uc2 "	;;Unified, 32b cache line, 4-way set associative, 265K	;:46
.UC5:	        dd "uc5 "	;;Unified, 32b cache line, 4-way set associative, 512K	;:47
.UC1M:	        dd "uc1m"	;;Unified, 32b cache line, 4-way set associative, 1M	;:48
.UC2M:		dd "uc2m"	;;Unified, 32b cache line, 4-way set associative, 2M	;:49
.TOP:
QUERY_NOT_FOUND:	;dd "xxxx"
		dd 0		;;							;:50
QUERY.e:
;; LABEL     Query-/Response-Stg::	Comment				Query Numbers ->;:nn;;;

%endif ;_AMD_CAPS_H
;-
;-===============================================================================;
;- cpucaps.inc <eof>
