;-===============================================================================;
;- Copyright (C) 2000 H-Peter Recktenwald, Berlin <phpr@snafu.de>
;-	GNU GPL, restricted to non-commercial useage, read
;-	LICENSE file for additional copyright information.
;-
;-  file  	: cpuid.defs.inc
;-  switch	: __CPUID_DEFS_I
;-  package	: "cpuid.tar.gz" with
;-  created	: 21-mar-2000
;-  modified	: 21-mar-2000
;-  version	: 0.16+
;-  assembler	: nasm 0.98
;-  description	: equate-s, etc, for cpuid.asm.
;-  author	: H-Peter Recktenwald, Berlin <phpr@snafu.de>
;-  comment	: to be included from "cpuid.asm",
;-		: after "system.inc" (asmutils), before any other stuff
;-  source	: (me)
;-  requires	:
;-===============================================================================;
;-
;- comments:
;-	i:	input data
;-	o:	output data
;-	c:	changed items
;-	<[val]>	effective address
;-	A	AMD specific
;-	I	Intel specific
;-	O	other manufacturers
;-	X	vendor/model independent
;-	-/-	item doesn't apply
;-	a_name	address
;-	a.name	bit
;-

%ifndef __CPUID_DEFS_I
%define __CPUID_DEFS_I

;-
;;-: debugging switches            				;
;- ssef
;-	test signal redirection for "ssef"
%define __DBG
;%undef	__DBG
%define __TEST
;%undef  __TEST
%undef  __ssef
%ifdef __DBG
%define __ssef
%endif
;-
;-
;;-: formatting flags  	  	    				;
;-	ioflagd,ioflagw,iflagb,oflagb
;-	i.flagw,o.flagw,v.flagd,n.flagd

%define ioflagd dword[byte esi-vref+i_opt]	; dword internal flags address
%define ioflagw  word[byte esi-vref+i_opt]	; word i/o-flags address
%define iflagb   byte[byte esi-vref+i_opt]	; byte input flags address
%define oflagb   byte[byte esi-vref+o_opt]	; byte output flags address
; ??? may be overdone...
%assign i.flagw  0	; add/shift for input flags bit-/(d)word-addressing per ioflagw/d
%assign o.flagw  8	; add/shift for output flags bit-/(d)word-addressing per ioflagw/d
%assign v.flagd 16	; add/shift for vendor vari bit-/dword-addressing per ioflagd
%assign n.flagd 24	; add/shift for aux. bit-/dword-addressing per ioflagd

;-
;-
;;-: passed as arguments      					;
;-
;;-: optf+0: cpuid options     					;
;- i_opt
;- request flags
;-	r_stg,r_lstg,r_qst,r_bl,r_bin,r_oct,r_hex,r_num
;- accumlative bitmasks
;-	r_digs (numeric),r_stgs (string)
;- request bits
;-	r.stg,r.lstg,r.qst,r.bl,r.bin,r.oct,r.hex,r.num
%define i_opt	optf
%assign r_stg	  1	; -s id-string (querystring)
%assign r_lstg	  2	; -l try for long strings
%assign r_qst	  4	; -? special query
%assign r_bl	  8	; -t don't append a trailing space to any output data
%assign r_bin	 16	; -b binary'b'
%assign r_oct	 32	; -o '0'octal
%assign r_hex	 64	; -x '0x'sedecimal
%assign r_num	128	; -n significant digits, only, w.o. numeric affix to flag values "0"/"1"
; corresponding bit numbers
%assign r.stg	0
%assign r.lstg	1
%assign r.qst	2
%assign r.bl	3
%assign r.bin	4
%assign r.oct	5
%assign r.hex	6
%assign r.num	7
; accumlative bitmasks
%assign r_digs	r_bin|r_oct|r_hex
%assign r_stgs	r_stg|r_lstg
;-

;-
;;-: internally generated      					;
;-
;;-: optf+1: ret. val. features    				;
;- o_opt
;- response flags (internal)
;-	o_ascis,o_estg,o_flag,o_dstg,o_lstg,o_ascil,o_quit  
;- accumlative bitmask
;-	o_bits (all but quit)
;- response bits (internal)
;-	o.ascis,o.estg,o.flag,o.dstg,o.lstg,o.ascil,o.quit
%define o_opt	(optf+1)
%assign o_ascis   1	; id(short) string is asciiz
%assign o_cstg	  2	; ecx is numeric
%assign o_flag	  4	; num is flag value
%assign o_dstg	 16	; edx is numeric
%assign o_lstg   32	; long string available
%assign o_ascil  64	; long string is asciiz
%assign o_quit  128	; quit after latest output
; corresponding bit numbers
%assign o.ascis	0
%assign o.estg	1	; ecx is numeric
%assign o.flag	2	; num is flag value
%assign o.dstg	4	; edx is numeric
%assign o.lstg	5
%assign o.ascil	6
%assign o.quit	7
; accumlative bitmasks
%assign o_bits	o_ascis|o_cstg|o_dstg|o_flag|o_lstg|o_ascil	; leave only quit as is

;-
;;-: optf+2: vendor found flag					;
;- o_vend
;- vendor numbers temp. storage
;-	o_vend,v_vend,m_vend,m_vendm
;-	v.vend
%define o_vend	(optf+2);(n.a.)
%assign v_vend	128	; vendor variable set
%assign m_vend	127	; mask for vendor code
%assign m_vendm 7	; max. no. of supported cpu vendors (AND mask, set to: 2^n-1)
;corresponding bit numbers
%assign v.vend	7	; vendor variable set

;-
;;-: optf+3:							;
;-	o_n.i	(yet unused)
%define o_n.i	(optf+3);(n.a.)

;-
;- disp's into cache level memory
;-	cb,c_a,c_b,c_c,c_d,cl0,cl1,cl2,cl3,cl4,cl5,cl6,cl7
%assign cb	16	; bytes per level
%assign c_a	0	; eax value disp into level
%assign c_b	4	; ebx
%assign c_c	8	; ecx
%assign c_d	12	; edx
%assign cl0	0	; level disp to memory base (last item for byte disp addressing!)
%assign cl1	1*cb
%assign cl2	2*cb
%assign cl3	3*cb
%assign cl4	4*cb
%assign cl5	5*cb
%assign cl6	6*cb
%assign cl7	7*cb

;-
;- equates
;-	bs,tab,lf,cr,del,eol
bs  equ  8
tab equ  9
lf  equ 10
cr  equ 13
del equ 127
eol equ lf

%endif; __CPUID_DEFS_I
;-
;-===============================================================================;
;- cpuid.defs.inc <eof>
