;-=========================================================================;
;- Copyright (C) 2000 H-Peter Recktenwald, Berlin <phpr@snafu.de>
;- Read LICENSE file for full copyright information (GNU GPL)
;-
;-  file  	: cpuid.test.inc
;-  switch	: __TEST_I, getting included only if both,
;-		: __TEST and __DBG, def'd prior to inclusion of this file.
;-  created	: 15-mar-00
;-  modified	: 24-mar-00
;-  version	: 0.17
;-  assembler	: nasm 0.98
;-  description	: data acquisition substitutes, test data inclusion
;-		: format description for substitute test datasets.
;-  author	: H-Peter Recktenwald, Berlin <phpr@snafu.de>
;-  comment	: outcomment dataset to test, below
;-  source	: (me)
;-  requires	: one of dummy datasets (or equivalent data):
;-		: ct.486DX-cpuid.dat,ct.486dx2_66.dat,
;-		: ct.Compaq-Presario-K6.dat,ct.k6_2_400.dat,
;-		: ct.pentium_90.dat,ct.pentium_III_450.dat,
;-		: ct.pentium_II_333.dat,ct.pentium_pro_150.dat
;-=========================================================================;
;-
;-

%ifdef __DBG
%ifdef __TEST
%ifndef __TEST_I
%define __TEST_I

%define cpu_id  call scpuid
%undef  chk_cpu
%define chk_cpu tcpu

;-
;- tdata
;-	dummy cpuid dataset
;- format:
;-	line by line results of a single cpuid level, sedecimal:
;-		'dd 0x{eax},0x{ebx},0x{ecx},0x{edx}'
;-	at least one of all zeroes if no cpuid instruction,
;-	additional last line 'dd 0' to terminating.
;-	no multiple dataset evaluation, 1st block being taken.
tdata:
;%include "ct.486DX-cpuid.dat"		; level 1 intel
;%include "ct.486dx2_66.dat"		; no cpuid	-> "u386"
;%include "ct.Compaq-Presario-K6.dat"	; levels 1 0x85
;%include "ct.amd0-dummy.dat"		; level 0 only	-> "a486"
;%include "ct.cpuid0-dummy.dat"		; level 0 only	-> "u486"
%include "ct.k6_2_400.dat"		; levels 1 0x85
;%include "ct.pentium_90.dat"		; level 1 intel
;%include "ct.pentium_III_450.dat"	; level 2 intel
;%include "ct.pentium_II_333.dat"	; level 2 intel
;%include "ct.pentium_pro_150.dat"	; level 2 intel

;-
;- tcpu
;-	dummy check for presence of cpuid instruction
;-	substitutes <check_cpu> in cpuid.asm
;-	called via %define-d <chk_cpu>
tcpu:
    push ecx
    mov [byte esi-vref+signature],eax			; pre-set family
    xor eax,eax
    cpu_id
    test ebx,ebx
    jnz .p						; present ?
    test eax,eax					; Z:no extensions nor features
.p:
    pop ecx
    ret

;-
;- scpuid
;-	cpuid substitute for testing purposes
;-	! cannot repeat on level 2 cache configuration calls !
;-	fetching test data from <tdata>+
scpuid:
    lea ebx,[tdata]
    mov ecx,[ebx]
    test eax,eax
    jns .s
    inc ecx
    shl ecx,4
    add ebx,ecx		; xlevel base
    mov ecx,[ebx]	; top level
    test ecx,ecx
    jz .n		; no xtd levels
.s:
    cmp eax,ecx
    ja .n		; level not available
    shl eax,4
    add ebx,eax		; ptr to level data
    mov eax,[ebx]
    mov ecx,[ebx+8]
    mov edx,[ebx+12]
    mov ebx,[ebx+4]
    ret
.n:
    xor eax,eax		; Z
    mov ebx,eax
    mov ecx,ebx
    mov edx,ebx
    ret

%endif ;__TEST_I
%endif ;__TEST
%endif ;__DBG
;-
;-=========================================================================;
;- cpuid.test.inc <eof>
